diff ios/dw.m @ 2673:a39e2ea6fa14

iOS: Only add the "Back" button to the Navigation Bar if the window has the DW_FCF_CLOSEBUTTON style, so it works like Android and generally like the other platforms... the "Back" button is equivalent to the close button. Also remove some more unicode from mobile.txt.
author bsmith@81767d24-ef19-dc11-ae90-00e081727c95
date Mon, 18 Oct 2021 13:29:55 +0000
parents 76d876c441c9
children dd0b29320a3d
line wrap: on
line diff
--- a/ios/dw.m	Mon Oct 18 12:55:29 2021 +0000
+++ b/ios/dw.m	Mon Oct 18 13:29:55 2021 +0000
@@ -8074,10 +8074,10 @@
             UINavigationBar* navbar = [[UINavigationBar alloc] initWithFrame:CGRectMake(0, sbheight, screenrect.size.width, 40)];
             UINavigationItem* navItem = [[UINavigationItem alloc] initWithTitle:nstitle];
 
             /* We maintain a list of top-level windows...
              * If there is more than one window, add a Back button that will close it.
              */
-            if([_dw_toplevel_windows count] > 1)
+            if([_dw_toplevel_windows count] > 1 && flStyle & DW_FCF_CLOSEBUTTON)
             {
                 UIBarButtonItem *back = [[UIBarButtonItem alloc] initWithTitle:@"Back"
                                                                          style:UIBarButtonItemStylePlain
@@ -8074,10 +8074,10 @@
             UINavigationItem* navItem = [[UINavigationItem alloc] initWithTitle:nstitle];
 
-            /* We maintain a list of top-level windows...
-             * If there is more than one window, add a Back button that will close it.
+            /* We maintain a list of top-level windows...If there is more than one window,
+             * and our window has the close button style, add a Back button that will close it.
              */